# Copyright 2026, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V24::Enums::CriterionTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                       => "UNSPECIFIED",
  UNKNOWN                           => "UNKNOWN",
  KEYWORD                           => "KEYWORD",
  PLACEMENT                         => "PLACEMENT",
  MOBILE_APP_CATEGORY               => "MOBILE_APP_CATEGORY",
  MOBILE_APPLICATION                => "MOBILE_APPLICATION",
  DEVICE                            => "DEVICE",
  LOCATION                          => "LOCATION",
  LISTING_GROUP                     => "LISTING_GROUP",
  AD_SCHEDULE                       => "AD_SCHEDULE",
  AGE_RANGE                         => "AGE_RANGE",
  GENDER                            => "GENDER",
  INCOME_RANGE                      => "INCOME_RANGE",
  PARENTAL_STATUS                   => "PARENTAL_STATUS",
  YOUTUBE_VIDEO                     => "YOUTUBE_VIDEO",
  YOUTUBE_CHANNEL                   => "YOUTUBE_CHANNEL",
  USER_LIST                         => "USER_LIST",
  PROXIMITY                         => "PROXIMITY",
  TOPIC                             => "TOPIC",
  LISTING_SCOPE                     => "LISTING_SCOPE",
  LANGUAGE                          => "LANGUAGE",
  IP_BLOCK                          => "IP_BLOCK",
  CONTENT_LABEL                     => "CONTENT_LABEL",
  CARRIER                           => "CARRIER",
  USER_INTEREST                     => "USER_INTEREST",
  WEBPAGE                           => "WEBPAGE",
  OPERATING_SYSTEM_VERSION          => "OPERATING_SYSTEM_VERSION",
  APP_PAYMENT_MODEL                 => "APP_PAYMENT_MODEL",
  MOBILE_DEVICE                     => "MOBILE_DEVICE",
  CUSTOM_AFFINITY                   => "CUSTOM_AFFINITY",
  CUSTOM_INTENT                     => "CUSTOM_INTENT",
  LOCATION_GROUP                    => "LOCATION_GROUP",
  CUSTOM_AUDIENCE                   => "CUSTOM_AUDIENCE",
  COMBINED_AUDIENCE                 => "COMBINED_AUDIENCE",
  KEYWORD_THEME                     => "KEYWORD_THEME",
  AUDIENCE                          => "AUDIENCE",
  NEGATIVE_KEYWORD_LIST             => "NEGATIVE_KEYWORD_LIST",
  LOCAL_SERVICE_ID                  => "LOCAL_SERVICE_ID",
  SEARCH_THEME                      => "SEARCH_THEME",
  BRAND                             => "BRAND",
  BRAND_LIST                        => "BRAND_LIST",
  LIFE_EVENT                        => "LIFE_EVENT",
  WEBPAGE_LIST                      => "WEBPAGE_LIST",
  VIDEO_LINEUP                      => "VIDEO_LINEUP",
  PLACEMENT_LIST                    => "PLACEMENT_LIST",
  VERTICAL_ADS_ITEM_GROUP_RULE_LIST => "VERTICAL_ADS_ITEM_GROUP_RULE_LIST",
  VERTICAL_ADS_ITEM_GROUP_RULE      => "VERTICAL_ADS_ITEM_GROUP_RULE",
  RETAIL_FILTER_BUNDLE              => "RETAIL_FILTER_BUNDLE",
  RETAIL_FILTER                     => "RETAIL_FILTER"
];

1;
