# Copyright 2026, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V24::Enums::ConversionActionCategoryEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED             => "UNSPECIFIED",
  UNKNOWN                 => "UNKNOWN",
  DEFAULT                 => "DEFAULT",
  PAGE_VIEW               => "PAGE_VIEW",
  PURCHASE                => "PURCHASE",
  SIGNUP                  => "SIGNUP",
  DOWNLOAD                => "DOWNLOAD",
  ADD_TO_CART             => "ADD_TO_CART",
  BEGIN_CHECKOUT          => "BEGIN_CHECKOUT",
  SUBSCRIBE_PAID          => "SUBSCRIBE_PAID",
  PHONE_CALL_LEAD         => "PHONE_CALL_LEAD",
  IMPORTED_LEAD           => "IMPORTED_LEAD",
  SUBMIT_LEAD_FORM        => "SUBMIT_LEAD_FORM",
  BOOK_APPOINTMENT        => "BOOK_APPOINTMENT",
  REQUEST_QUOTE           => "REQUEST_QUOTE",
  GET_DIRECTIONS          => "GET_DIRECTIONS",
  OUTBOUND_CLICK          => "OUTBOUND_CLICK",
  CONTACT                 => "CONTACT",
  ENGAGEMENT              => "ENGAGEMENT",
  STORE_VISIT             => "STORE_VISIT",
  STORE_SALE              => "STORE_SALE",
  QUALIFIED_LEAD          => "QUALIFIED_LEAD",
  CONVERTED_LEAD          => "CONVERTED_LEAD",
  YOUTUBE_FOLLOW_ON_VIEWS => "YOUTUBE_FOLLOW_ON_VIEWS"
];

1;
