# Copyright 2026, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V25::Enums::LocalServicesLeadSurveyDissatisfiedReasonEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED               => "UNSPECIFIED",
  UNKNOWN                   => "UNKNOWN",
  OTHER_DISSATISFIED_REASON => "OTHER_DISSATISFIED_REASON",
  GEO_MISMATCH              => "GEO_MISMATCH",
  JOB_TYPE_MISMATCH         => "JOB_TYPE_MISMATCH",
  NOT_READY_TO_BOOK         => "NOT_READY_TO_BOOK",
  SPAM                      => "SPAM",
  DUPLICATE                 => "DUPLICATE",
  SOLICITATION              => "SOLICITATION"
];

1;
