# Copyright 2026, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V25::Enums::AdFormatTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED               => "UNSPECIFIED",
  UNKNOWN                   => "UNKNOWN",
  OTHER                     => "OTHER",
  UNSEGMENTED               => "UNSEGMENTED",
  INSTREAM_SKIPPABLE        => "INSTREAM_SKIPPABLE",
  INSTREAM_NON_SKIPPABLE    => "INSTREAM_NON_SKIPPABLE",
  INFEED                    => "INFEED",
  BUMPER                    => "BUMPER",
  OUTSTREAM                 => "OUTSTREAM",
  MASTHEAD                  => "MASTHEAD",
  AUDIO                     => "AUDIO",
  SHORTS                    => "SHORTS",
  PAUSE                     => "PAUSE",
  VERTICAL_ADS_PROMOTION    => "VERTICAL_ADS_PROMOTION",
  VERTICAL_ADS_BOOKING_LINK => "VERTICAL_ADS_BOOKING_LINK",
  TEXT                      => "TEXT"
];

1;
