# Copyright 2026, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V25::Enums::RegulatoryFeeTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                       => "UNSPECIFIED",
  UNKNOWN                           => "UNKNOWN",
  AUSTRIA_DST_FEE                   => "AUSTRIA_DST_FEE",
  TURKIYE_REGULATORY_OPERATING_COST => "TURKIYE_REGULATORY_OPERATING_COST",
  UK_DST_FEE                        => "UK_DST_FEE",
  SPAIN_REGULATORY_OPERATING_COST   => "SPAIN_REGULATORY_OPERATING_COST",
  FRANCE_REGULATORY_OPERATING_COST  => "FRANCE_REGULATORY_OPERATING_COST",
  ITALY_REGULATORY_OPERATING_COST   => "ITALY_REGULATORY_OPERATING_COST",
  INDIA_REGULATORY_OPERATING_COST   => "INDIA_REGULATORY_OPERATING_COST",
  POLAND_REGULATORY_OPERATING_COST  => "POLAND_REGULATORY_OPERATING_COST",
  OPERATING_CHARGES                 => "OPERATING_CHARGES",
  CANADA_DST_FEE                    => "CANADA_DST_FEE"
];

1;
